// joi/1/lights/NextButtonListener.java                         
//                                                            
//                                                            
// Copyright 2003 Bill Campbell and Ethan Bolker                         
                                                            
import java.awt.event.*;

/**
 * A NextButtonListener sends a "next" message to its
 * Sequencer each time a button to which it is listening
 * is pressed.
 *
 * @version 1
 */

public class NextButtonListener implements ActionListener
{
    private Sequencer sequencer;
    
    /**
     * Construct a listener that "listens for" a user's
     * pressing the "Next" button.
     *
     * @param sequencer the Sequencer for the TrafficLight.
     */

    public NextButtonListener( Sequencer sequencer )
    {
	this.sequencer = sequencer;
    }

    /**
     * The action performed when a push of the button is detected:
     * send a next message to the Sequencer to advance it to
     * its next state.
     *
     * @param event the event detected at the button.
     */

    public void actionPerformed( ActionEvent event )
    {
	this.sequencer.next();
    }
}
