// joi/1/lights/Sequencer.java                         
//                                                            
//                                                            
// Copyright 2003 Bill Campbell and Ethan Bolker                         
                                                            
/**
 * A Sequencer controls a TrafficLight. It maintains fields 
 * for the light itself and the current state of the light. 
 * 
 * Each time it receives a "next" message, it advances to the 
 * next state and sends the light an appropriate message.
 *
 * @version 1
 */

public class Sequencer
{
    // the TrafficLight this Sequencer controls
    private TrafficLight light;   

    // represent the states by ints
    private final static int GO       = 0; 
    private final static int CAUTION  = 1;
    private final static int STOP     = 2;
    
    private int currentState;            

    /**
     * Construct a sequencer to control a TrafficLight.
     *
     * @param light the TrafficLight we wish to control.
     */

    public Sequencer( TrafficLight light )
    {
	this.light = light;
	this.currentState = GO;
	this.light.setGo();
    }

    /**
     * How the light changes when a next Button is pressed 
     * depends on the current state. The sequence is
     * GO -> CAUTION -> STOP -> GO.
     */

    public void next()
    {
	switch ( currentState ) {
	    
	case GO: 
	    this.currentState = CAUTION;
	    this.light.setCaution();
	    break;
	    
	case CAUTION:
	    this.currentState = STOP;
	    this.light.setStop();
	    break;
	    
	case STOP:
	    this.currentState = GO;
	    this.light.setGo();
	    break;

	default: // This will never happen
	    System.err.println("What color is the light?!");
	}
    }
}
