// joi/1/lights/TrafficLight.java                         
//                                                            
//                                                            
// Copyright 2003 Bill Campbell and Ethan Bolker                         
                                                            
import java.awt.*;
import java.awt.event.*;

/**
 * A TrafficLight has three lenses: red, yellow and green.
 * It can be set to signal Go, Caution, Stop or Walk.
 *
 * @version 1
 */

public class TrafficLight extends Panel
{
    // Three Lenses and a Button

    private Lens red          = new Lens( Color.red );
    private Lens yellow       = new Lens( Color.yellow );
    private Lens green        = new Lens( Color.green );
    private Button nextButton = new Button("Next"); 

    /**
     * Construct a traffic light.
     */

    public TrafficLight()
    {
        this.setLayout(new BorderLayout());

        // create a Panel for the Lenses
        Panel lensPanel = new Panel();
        lensPanel.setLayout( new GridLayout( 3, 1 ) );
        lensPanel.add( red );
        lensPanel.add( yellow );
        lensPanel.add( green );
        this.add( BorderLayout.NORTH, lensPanel );

        // configure the "Next" button
        Sequencer sequencer = new Sequencer( this );
        NextButtonListener payAttention = 
            new NextButtonListener( sequencer );
        nextButton.addActionListener( payAttention );
        this.add( BorderLayout.CENTER, nextButton);
    }

    // Methods that change the light

    /**
     * Set the light to stop (red).
     */

    public void setStop()
    {
        red.turnOn();
        yellow.turnOff();
        green.turnOff();
    }
    
    /**
     * Set the light to caution (yellow).
     */

    public void setCaution()
    {
        red.turnOff();
        yellow.turnOn();
        green.turnOff();
    }
    
    /**
     * Set the light to go (green).
     */

    public void setGo()
    {
        red.turnOff();
        yellow.turnOff();
        green.turnOn();
    }
    
    /**
     * Set the light to walk.
     *
     * (In Boston, red and yellow signal walk.)
     */

    public void setWalk()
    {
        red.turnOn();
        yellow.turnOn();
        green.turnOff();
    }

    /**
     * The traffic light simulation starts at main.
     *
     * @param args ignored.
     */

    public static void main( String[] args )
    {
        Frame frame         = new Frame();
        TrafficLight light  = new TrafficLight();
        frame.add( light );
        frame.addWindowListener( new ShutDownLight() );
        frame.pack();
        frame.show();
    }

     // A ShutDownLight instance handles close events generated
     // by the underlying window system with its windowClosing
     // method.
     //
     // This is an inner class, declared inside the
     // TrafficLight class since it's used only here.

    private static class ShutDownLight extends WindowAdapter
    {
         // Close the window by shutting down the light.

        public void windowClosing (WindowEvent e) 
        {
            System.exit(0);
        }
    }
}


