// joi/10/juno/User.java                         
//                                                            
//                                                            
// Copyright 2003 Ethan Bolker and Bill Campbell                         
                                                            
/**
 * Model a juno user.  Each User has a login name, password,
 * a home directory, and a real name.
 * name.
 *
 * @version 10
 */

public class User 
    implements java.io.Serializable
{
    private String name;     // the User's login name
    private String password; // The user's login password.
    private Directory home;  // her home Directory
    private String realName; // her real name

    /**
     * Construct a new User.
     *
     * @param name      the User's login name.
     * @param password  the user's login password.
     * @param home      her home Directory.
     * @param realName  her real name.
     */

    public User( String name, String password, 
		 Directory home, String realName ) 
    {
	this.name     = name;
	this.password = password;
	this.home     = home;
	this.realName = realName;
    }

    /**
     *   Confirm password. Throw a JunoException on failure.
     *
     *   @param guess the string to test against the password.
     *
     *   @exception JunoException
     *      if password fails to match
     */

    public void matchPassword( String guess ) throws JunoException 
    {
        if (!guess.equals( password )) {
            throw new JunoException( "bad password" );
	}
    }
    
    /**
     * Get the User's login name.
     *
     * @return the name.
     */

    public String getName()    
    {
        return name;
    }

    /**
     * Convert the User to a String.
     * The String representation for a User is her
     * login name.
     *
     * @return the User's name.
     */

    public String toString()   
    {
        return getName();
    }
    
    /**
     * Get the User's home Directory.
     *
     * @return the home Directory.
     */

    public Directory getHome() 
    {
        return home;
    }

    /**
     * Get the user's real name.
     *
     * @return the real name.
     */

    public String getRealName()
    {
        return realName;
    }
}
