// joi/3/shapes/Box.java                         
//                                                            
//                                                            
// Copyright 2003 Bill Campbell and Ethan Bolker                         
                                                            
/**
 * A Box has a width, a height and a paintChar used 
 * used to paint the Box on a Screen.
 *
 * Examples:
 * <pre>
 *  new Box( 3, 4, 'G' )   new Box( 1, 1, '$' )
 *
 *          GGG                     $
 *          GGG
 *          GGG
 *          GGG
 * </pre>
 *
 * @version 3
 */

public class Box
{
    private int  width;      // width  in (character) pixels
    private int  height;     // height in (character) pixels
    private char paintChar;  // character used for painting

    /**
     * Construct a box.
     *
     * @param width width in (character) pixels.
     * @param height height in (character) pixels.
     * @param paintChar character used for painting this Box.
     */

    public Box( int width, int height, char paintChar )
    {
        this.width     = width;
        this.height    = height;
        this.paintChar = paintChar;
    }

    /**
     * Paint this Box on Screen s at position (x,y).
     *
     * @param s the screen on which this box is to be painted.
     * @param x the x position for the box.
     * @param y the y position for the box.
     */
        
    public void paintOn( Screen s, int x, int y )
    {
        HLine hline = new HLine( width, paintChar );
        for ( int i = 0; i < height; i++ ) {
            hline.paintOn( s, x, y+i );
        }
    }

    /**
     * Paint this Box on Screen s at position (0,0).
     *
     * @param s the Screen on which this box is to be painted.
     */
        
    public void paintOn( Screen s )
    {
        paintOn( s, 0, 0 );  // or this.paintOn(s,0,0);
    }

    /**
     * Get the width of this Box.
     *
     * @return width of box (expressed as a number 
     *         of characters).
     */

    public int getWidth()
    {
        return width;
    }
    
    /**
     * Get the height of this Box.
     *
     * @return the height in (character) pixels. 
     */

    public int getHeight()
    {
        return height;
    }

    /**
     * Set the width of this Box.
     *
     * @param width the new width in (character) pixels.
     */

    public void setWidth( int width )
    {
        this.width = width;
    }
    
    /**
     * Set the height of this Box.
     *
     * @param height the new height in (character) pixels.
     */

    public void setHeight( int height )
    {
        this.height = height;
    }

    /**
     * Unit test for class Box,
     * assuming Screen and Terminal work.
     */

    public static void main( String[] args )
    {
        Terminal terminal = new Terminal();

        terminal.println( "Unit test of Box.");
        terminal.println( "You should see this Screen twice: " );
        terminal.println( "++++++++++++++++++++++");
        terminal.println( "+RRRR                +");
        terminal.println( "+RRRR                +");
        terminal.println( "+RRGGG               +");
        terminal.println( "+RRGGG               +");
        terminal.println( "+RRGGG               +");
        terminal.println( "+  GGRRRRRRR         +");
        terminal.println( "++++++++++++++++++++++");
        terminal.println();

        Screen screen   = new Screen( 20, 6 );
        
        Box box1 = new Box( 4, 5, 'R' );
        Box box2 = new Box( 3, 4, 'G' );
        
        box1.paintOn( screen );
        box2.paintOn( screen, 2, 2 );

        // test reference model for objects
        box2 = box1;
        int oldWidth = box2.getWidth();
        box1.setWidth(oldWidth+3);
        box2.paintOn( screen, 4, 5 );

        screen.draw( terminal );
    }
}
