// joi/3/shapes/HLine.java                         
//                                                            
//                                                            
// Copyright 2003 Bill Campbell and Ethan Bolker                         
                                                            
/**
 * A horizontal line has a length and a paintChar used
 * used to paint the line on a Screen.
 *
 * @version 3
 */

public class HLine
{
    private int  length;      // length in (character) pixels.
    private char paintChar;   // character used for painting.

    /**
     * Construct an HLine.
     *
     * @param length length in (character) pixels.
     * @param paintChar character used for painting this Line.
     */

    public HLine( int length, char paintChar )
    {
        this.length = length;
        this.paintChar = paintChar;
    }

    /**
     * Paint this HLine on Screen s at position (x,y).
     *
     * @param s the Screen on which this line is to be painted.
     * @param x the x position for the line.
     * @param y the y position for the line.
     */

    public void paintOn( Screen s, int x, int y )
    {
        for ( int i = 0; i < length; i = i+1 ) {
            s.paintAt( paintChar, x+i , y );
        }
    }

    /**
     * Paint this HLine on Screen s at position (0,0).
     *
     * @param s the Screen on which this line is to be painted.
     */

    public void paintOn( Screen s )
    {
        paintOn( s, 0, 0 );
    }

    /**
     * Get the length of this line.
     *
     * @return the length in (character) pixels. 
     */

    public int getLength()
    {
        return length;
    }

    /**
     * Set the length of this line.
     *
     * @param length the new length in (character) pixels.
     */

    public void setLength( int length )
    {
        this.length = length;
    }

    /**
     * Unit test for class HLine, 
     * assuming Screen and Terminal work.
     */

    public static void main( String[] args )
    {
        Terminal terminal = new Terminal();

        terminal.println( "Unit test of HLine.");
        terminal.println( "You should see this Screen twice: " );
        terminal.println( "++++++++++++++++++++++");
        terminal.println( "+xxxxxxxxxx          +");
        terminal.println( "+xxxxx               +");
        terminal.println( "+                    +");
        terminal.println( "+   *****            +");
        terminal.println( "+    1               +");
        terminal.println( "+                    +");
        terminal.println( "++++++++++++++++++++++");
        terminal.println( "");

        Screen   screen   = new Screen( 20, 6 );

        HLine hline1 = new HLine( 10, 'x' );
        HLine hline2 = new HLine(  5, '*' );
        HLine hline3 = new HLine(  1, '1' );

        hline1.paintOn( screen );
        hline1.setLength(5);
        hline1.paintOn( screen, 0, 1 );
        hline2.paintOn( screen, 3, 3 );
        hline3.paintOn( screen, 4, 4 );

        screen.draw( terminal );
    }
} 
