// joi/5/jfiles/TextFile.java                         
//                                                            
//                                                            
// Copyright 2003 Ethan Bolker and Bill Campbell                         
                                                            
/**
 * A TextFile is a JFile that holds text.
 *
 * @version 5
 */

public class TextFile extends JFile 
{
    private String contents;  // The text itself

    /** 
     * Construct a TextFile with initial contents.
     *
     * @param name    the name for this TextFile (in its parent Directory)
     * @param creator the owner of this new TextFile
     * @param parent  the Directory in which this TextFile lives.
     * @param initialContents the initial text
     */

    public TextFile( String name, String creator, Directory parent,
              String initialContents ) 
    {
        super( name, creator, parent );
        setContents( initialContents );
    }

    /** 
     * Construct an empty TextFile.
     *
     * @param name    the name for this TextFile (in its parent Directory)
     * @param creator the owner of this new TextFile
     * @param parent  the Directory in which this TextFile lives
     */

    TextFile( String name, String creator, Directory parent ) 
    {
        this( name, creator, parent, "" );
    }
    
    /**
     * The size of a text file is the number of characters stored.
     *
     * @return the file's size.
     */

    public int getSize()
    {
        return contents.length();
    }

    /**
     * Suffix used for printing text file names is "".
     *
     * @return an empty suffix (for TextFiles).
     */

    public String getSuffix()
    {
        return "";
    }

    /**
     * Replace the contents of the file.
     *
     * @param contents the new contents.
     */

    public void setContents( String contents ) 
    {
        this.contents = contents;
        setModDate();
    }

    /**
     * The contents of a text file.
     *
     * @return String contents of the file.
     */

    public String getContents() 
    {
        return contents;
    }

    /**
     * Append text to the end of the file.
     *
     * @param  text the text to be appended.
     */

    public void append( String text ) 
    {
        setContents( contents + text );
    }


    /**
     * Append a new line of text to the end of the file.
     *
     * @param  text the text to be appended.
     */

    public void appendLine( String text )
    {
        this.setContents(contents + '\n' + text);
    }
}
