// joi/6/juno/HelpCommand.java                         
//                                                            
//                                                            
// Copyright 2003, Ethan Bolker and Bill Campbell                         
                                                            
import java.util.*;

/**
 * The Juno shell command to display help on the shell commands.
 * Usage:
 * <pre>
 *     help
 * </pre>
 *
 * @version 6
 */

public class HelpCommand extends ShellCommand 
{
    /**
     * Construct a HelpCommand object.
     */

    HelpCommand() 
    {
        super( "display ShellCommands" );
    }

    /**
     * Display help for all commands.
     *
     * @param args the remainder of the command line.
     * @param sh the current shell
     */

    public void doIt( StringTokenizer args, Shell sh )
    {
        // Get command keys from global table, print them out, 
        // followed by command's help string.
        
        sh.getConsole().println( "shell commands" );
        ShellCommandTable table = sh.getSystem().getCommandTable();
        String[] names = table.getCommandNames();
        for (int i = 0; i < names.length; i++ ) {
            String cmdname = names[i];
            ShellCommand cmd = table.lookup( cmdname );
            sh.getConsole().
                println( "  " + cmdname + ": " + cmd.getHelpString() );
        }
    }
}
