// joi/6/juno/ShellCommand.java                         
//                                                            
//                                                            
// Copyright 2003 Ethan Bolker and Bill Campbell                         
                                                            
import java.util.*;

/**
 * Model those features common to all ShellCommands. 
 * 
 * Each concrete extension of this class provides a constructor 
 * and an implementation for method doIt.
 *
 * @version 6
 */

public abstract class ShellCommand 
{
    private String helpString;   // documents the command
    private String argString;    // any args to the command

    /** 
     * A constructor, always called (as super()) by the subclass.
     * Used only for commands that have arguments.
     *
     * @param helpString a brief description of what the command does.
     * @param argString a prototype illustrating the required arguments.
     */

    protected ShellCommand( String helpString, String argString )
    {
        this.argString  = argString;
        this.helpString = helpString;
    }
    
    /**
     * A constructor for commands having no arguments.
     *
     * @param helpString a brief description of what the command does.
     */

    protected ShellCommand( String helpString ) 
    {
        this( helpString, "" );
    }
    
    /**
     * Execute the command.
     *
     * @param args the remainder of the command line.
     * @param sh   the current shell
     */

    public abstract void doIt( StringTokenizer args, Shell sh );

    /**
     * Help for this command.
     *
     * @return the help string.
     */

    public String getHelpString()
    {
        return helpString;
    }
    
    /**
     * The argument string prototype.
     *
     * @return the argument string prototype.
     */

    public String getArgString()
    {
        return argString;
    }
}
